/*
 * Copyright (C) 2009 Cjacker Huang <jzhuang@redflag-linux.com>.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifdef __BLOCKS__
#undef __BLOCKS__
#endif

#ifndef HS_WEBKIT_H
#define HS_WEBKIT_H
/* to avoid stdbool.h error in JavaScriptCore/JSBase.h*/
#define _Bool int

#define WINAPI
#define CALLBACK

/* include webkit headers*/
#include <webkit/webkit.h>
#include <webkit/webkitdom.h>
#endif

#include "events.h"
